# Moss CAPPA
Python-клиент [Moss](http://theory.stanford.edu/~aiken/moss/), предназначенный для использования в комплексе автоматической проверки программ [CAPPA](http://cappa.csu.ru/). 

Основан на [moss.py](https://github.com/soachishti/moss.py) и [MOSS-PHP](https://github.com/Phhere/MOSS-PHP)

[Пример использования](docs/usage.md)

### Контакты
Официальный сайт: [cappa.csu.ru](http://cappa.csu.ru/)   

Ответственный разработчик: Прядка Владислав

По вопросам сотрудничества: mig19@mail.ru

При поддержке:
 * [Математический факультет ЧелГУ](http://math.csu.ru)

### Лицензия
Распространяется под лицензией [MIT](LICENSE).